# -*- coding: utf-8 -*-
## Copyright (C) 2001-2008 Red Hat, Inc.
## Copyright (C) 2001-2008 Harald Hoyer <harald@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

'''
boot_gui.py - GUI front end code for boot configuration
'''

import gtk, gobject, sys, dbus, logging
#from rhpl.translate import _, N_
from policykit import PolicyKitAuthentication

POLICY_KIT_ACTION = 'org.gnome.xkit.configure'#'com.redhat.conf.grub.access'
SERVICE_NAME   = 'org.gnome.XKit.Mechanism'#'com.redhat.conf.grub.Mechanism'
OBJECT_PATH    = '/'
INTERFACE_NAME = 'org.gnome.XKit.Mechanism'#'com.redhat.conf.grub.Mechanism'

def get_xkit_service(widget=None):
    '''
    returns a dbus interface to the grub.conf mechanism
    '''
    policy_auth = PolicyKitAuthentication()    

    granted = policy_auth.obtain_authorization(POLICY_KIT_ACTION, widget)
    logging.debug("granted = %s" % granted)

    if not granted:
        return None
    
    service_object = dbus.SystemBus().get_object(SERVICE_NAME, OBJECT_PATH)
    service = dbus.Interface(service_object, INTERFACE_NAME)

    return service

def gui_error_dialog (message, parent_dialog,
                      message_type=None,
                      widget=None, page=0, 
                      broken_widget=None):
    '''
    Displays an error dialog.
    '''
    if message_type == None:
        message_type = gtk.MESSAGE_ERROR


    logging.error(message)
        
    dialog = gtk.MessageDialog(parent_dialog,
                               gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,
                               message_type, gtk.BUTTONS_OK,
                               message)
    
    if widget != None:
        if isinstance (widget, gtk.CList):
            widget.select_row (page, 0)
        elif isinstance (widget, gtk.Notebook):
            widget.set_current_page (page)
    if broken_widget != None:
        broken_widget.grab_focus ()
        if isinstance (broken_widget, gtk.Entry):
            broken_widget.select_region (0, -1)

    if parent_dialog:
        dialog.set_position (gtk.WIN_POS_CENTER_ON_PARENT)
        dialog.set_transient_for(parent_dialog)
    else:
        dialog.set_position (gtk.WIN_POS_CENTER)

    ret = dialog.run ()
    dialog.destroy()    

    return ret



class BootWindow:
    def __init__(self):#stand_alone(self, doDebug = None):
        self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
        self.window.connect("delete_event", self.on_delete_event)
        self.window.connect("destroy", self.on_destroy)

        self.button = gtk.Button("Obtain Authorization")
        self.button.connect("clicked", self.on_button_clicked, None)
        self.window.add(self.button)
        self.button.show()
    
    def on_button_clicked(self, widget, data=None):
        self.conf = get_xkit_service()
        if not self.conf:
            gui_error_dialog("Could not connect to XKit DBUS service.",
                              self.mainWindow)
            sys.exit(10)
        #pass
        
    def on_delete_event(self, widget, event, data=None):
        # Close the window:
        return False

    def on_destroy(self, widget, data=None):
        gtk.main_quit()

    def show(self):
       self.window.show()

window = BootWindow()
window.show()
gtk.main()
